% Simulations for ambiguous stimuli

clear;

spacing= 'linear';

% Time linear-spacing
minPitch=	30; maxPitch=	10000; numPitches=150;
maxLag=1/minPitch; minLag=1/maxPitch;
lags= linspace(minLag, maxLag, numPitches);
lag_num= length(lags);

% Frequency log-spacing
if strcmp(spacing, 'log')
    a= log10(minPitch);
    b= log10(maxPitch);
    vector= logspace(a, b, numPitches);
    lags= 1./vector;
end

CFlags1=0.5;
CFlags2=15;

CFlags1=0;
CFlags2=350;


type_model= 'SACF'; % 'SACF'

plots=0;

ANrepr= 'probability'; % spikes
% ANrepr= 'spikes';

spectrum= 'Low';

currentF= pwd;
currentF=currentF(1:length(currentF)-15);
currentFWav=strcat(currentF,'wavFileStore');
folderAmb = fullfile(currentFWav, 'Ambiguous');

outputFolder= fullfile(currentF, 'Results', 'Ambiguous');
if ~isdir(outputFolder),
    mkdir(outputFolder);
end
% Gets all files in directory
listingAmb = dir(folderAmb);

namesAmb = struct2cell(listingAmb);
namesAmb= namesAmb(1,3:size(namesAmb,2));

num_Amb= length(namesAmb);

amb_SACFs= zeros(num_Amb, lag_num);

for i=1:num_Amb, % obtains SACF function for each ambiguous stimuli
    shortname= namesAmb{i};
    short_len=length(shortname);
    filename= fullfile(folderAmb, shortname);
    [LP_SACF, dt, lags, SACF, ANprob, inputSignal, fs, BFList]= FullPitchModel(filename, lags, CFlags1, CFlags2, ANrepr);
%     LP_SACFmean= mean(LP_SACF,2);
    SACFmean= mean(SACF,2);
    amb_SACFs(i,:)=SACFmean;

    [pks,locs] = findpeaks(SACFmean);
    peakLags= lags(locs);
    
    nombreFig= fullfile(outputFolder, shortname(1:short_len-4));
    nombreFig= strcat(nombreFig,'#', num2str(numPitches), spacing, num2str(floor(10*CFlags1)), '-', num2str(floor(10*CFlags2)));
    h=figure('Name','SACF','visible', 'off');
    plot(lags, SACFmean, '-b', peakLags, pks, 'ro')
    xlabel('Lag(s)')
    ylabel('SACF')
    saveas ( h, nombreFig, 'png' )
    close(h)
    
    peakFreqs= 1./peakLags;
    save(nombreFig, 'peakLags', 'peakFreqs');
    
end




