% Simulations for dominance region

function DominanceFunction(numPitches, CFlags1, CFlags2, spacing)
% DOMINANCEFUNCTION computes the dominance region for a particular configuration 
% NUMPITCHES is the number of lags used
% CFLAGS1 is the start of the lag range, as a function of CF [CFLAGS1/CF, CFLAGS2/CF]
% CFLAGS2 is the end of the lag range, as a function of CF
% SPACING is the type of spacing used

% Time linear-spacing
minPitch=	30; maxPitch=	10000; %numPitches=150;
maxLag=1/minPitch; minLag=1/maxPitch;
lags= linspace(minLag, maxLag, numPitches);
lag_num= length(lags);

% Frequency log-spacing
if strcmp(spacing,'log'),
    a= log10(30);
    b= log10(10000);
    vector= logspace(a, b, numPitches);
    lags= 1./vector;
end

ANrepr= 'probability'; % spikes

currentF= pwd;
currentF=currentF(1:length(currentF)-15);
currentFWav=strcat(currentF,'wavFileStore');
folderRef = fullfile(currentFWav, 'Dominance');

outputFolder= fullfile(currentF, 'Results', 'Dominance');
if ~isdir(outputFolder),
    mkdir(outputFolder);
end

% Gets all files in directory
listingRef = dir(folderRef);
namesRef = struct2cell(listingRef);
namesRef= namesRef(1,3:length(namesRef));

num_ref= length(namesRef);
ref_SACFs= zeros(num_ref, lag_num);

lastPeaks=zeros(2,1);

Freqs= [200, 300, 450, 675];
mvalue=zeros(1,4);

nextPitch=0;
lastPitch=0;
j=1;

for i=1:num_ref, % for each ref stimuli, obtains SACF function
    shortname=namesRef{i};
    filename= fullfile(folderRef, shortname);
    
    k1=strfind(shortname, '(');
    k2=strfind(shortname, 'Hz');
    k3=strfind(shortname, '.wav');
    pitch= str2double(shortname(k1+1:k2-1));
    m= str2double(shortname(k2+3:k3-1));
    if lastPitch~=pitch, % if pitch is different than last
        nextPitch=0;
    end
    lastPitch=pitch;
    if nextPitch==0,
        [LP_SACF, dt, lags, SACF, ANprob, inputSignal, fs, BFList]= FullPitchModel(filename, lags, CFlags1, CFlags2, ANrepr);
    %     LP_SACFmean= mean(LP_SACF,2);
        SACFmean= mean(SACF,2);
        ref_SACFs(i,:)=SACFmean;

        lag1=1/(1.1*pitch);
        lag2=1/(0.9*pitch);           
        
        pks= interp1(lags,SACFmean,[lag1,lag2]);

        if pks(1)<pks(2), % When peak is near 0.9F0 no more m calculation is needed for this pitch
            nextPitch=1;
            % Interpolate to obtain m corresponding to peak curve crossing (Linear)
            A= pks(2)-lastPeaks(2); % Slope first curve
            B= pks(1)-lastPeaks(1); % Slope second curve
            C= lastPeaks(1)-lastPeaks(2); % Second curve constant
            X= C/(A-B);
            if m==1
                mvalue(j)=1;
            else 
                mvalue(j)= m-1+X;
            end
            j=j+1;
        end
        lastPeaks=pks;
    end
end

nombreFig= fullfile(outputFolder, 'Dominance');
nombreFig= strcat(nombreFig,'#', num2str(numPitches), spacing, num2str(floor(10*CFlags1)), '-', num2str(floor(10*CFlags2)));
h=figure('Name','Dominance','visible', 'off');
plot(Freqs, mvalue);
xlabel('Frequency of fundamental (Hz)')
ylabel('Harmonic number')
grid on
saveas ( h, nombreFig, 'png' )
saveas ( h, nombreFig, 'fig' )

save(nombreFig, 'mvalue');
close(h)

end