function FDLs(numPitches, CFlags1, CFlags2, spacing)

% Time linear-spacing
minPitch=	30; maxPitch=	10000;
maxLag=1/minPitch; minLag=1/maxPitch;
lags= linspace(minLag, maxLag, numPitches);

% Frequency log-spacing
if strcmp(spacing, 'log')
    a= log10(minPitch);
    b= log10(maxPitch);
    vector= logspace(a, b, numPitches);
    lags= 1./vector;
end

delta_num=60;

type_model= 'SACF'; % 'SACF' or 'LP_SACF'

plots=0;
plot_deltas=0;

thresholdD2= 5*10^4;

ANrepr= 'probability'; % spikes
% ANrepr= 'spikes';

currentF= pwd;
currentF=currentF(1:length(currentF)-15);
currentFWav=strcat(currentF,'wavFileStore');
folderRef = fullfile(currentFWav, 'FDLs', 'Ref');
folderDeltas = fullfile(currentFWav, 'FDLs', 'Deltas');

outputFolder= fullfile(currentF, 'Results', 'FDLs');
if ~isdir(outputFolder),
    mkdir(outputFolder);
end

% Gets all files in directory
listingRef = dir(folderRef);
listingDeltas = dir(folderDeltas);

num_ref= length(listingRef);
num_deltas= length(listingDeltas);

deltas= GetDeltas(delta_num);
FDL= zeros(8,1);
FDLFreqs= [250, 500, 1000, 2000, 4000, 5000, 6300, 8000];
% FDLFreqs= [4000, 4500, 5000, 5500, 6000, 6300, 6800, 8000];
% FDLFreqs=[5500, 6000, 6200, 6300, 6450, 6700, 7000, 8000];

for i=3:10, % For every frequency it computes corresponding FDL
    SACFd_index= zeros(delta_num,1);
    LP_SACFd_index= zeros(delta_num,1);

    name= listingRef(i).name;
    fileName=fullfile(folderRef,name);
    % fileName= 'ComplexTone(50Hz31)LowSineDelta0';
    [LP_SACF, dt, lags, SACF, ANprob, inputSignal ,fs, BFList, numLags]= FullPitchModel(fileName, lags, CFlags1, CFlags2, ANrepr);
    LP_SACFmean= mean(LP_SACF,2);
    SACFmean= mean(SACF,2);
    
    name2= name(1:length(name)-4);
    
    % SAVE FIGURES: stimulus, total firing probability and SACF
    if plots==1,
        nombreFig= fullfile(outputFolder,'SACF-FDLref', name2);
        
        h=figure('Name','Simulation','visible', 'off');

        t= (1/fs):(1/fs):(length(inputSignal)/fs);
        subplot(311)
        plot(t(t<0.02),inputSignal(t<0.02));
        xlabel('Time(s)')
        ylabel('Signal')
        grid on
        
        subplot(312)
        ANprobmean= mean(ANprob,1);
        ANprobmean=ANprobmean(round(t*fs));
        plot(t(t<0.02), ANprobmean(t<0.02))
        xlabel('Time(s)')
        ylabel('Probability of firing')
        grid on

        subplot(313)
        plot(lags, SACFmean)
        xlabel('Lag(s)')
        ylabel('SACF')
        grid on

        saveas ( h, nombreFig, 'png' )
        close(h)
    % Plots firing prob for all channels
    else if plots==2,
        nombreDir= fullfile(outputFolder,'ProbDisparoCanales', name2);
        if ~isdir(nombreDir),
            mkdir(nombreDir);
        end
        
        for canal=1:size(ANprob,1),

            nombreFig=fullfile(nombreDir,num2str(BFList(canal)));
            h=figure('Name','Simulation','visible', 'off');
            t= (1/fs):(1/fs):(length(inputSignal)/fs);
            subplot(211)
            plot(t(t<0.02),inputSignal(t<0.02));
            xlabel('Time(s)')
            ylabel('Signal')
            grid on

            subplot(212)
            ANprobc= ANprob(canal,:);
            ANprobc=ANprobc(round(t*fs));
            plot(t(t<0.02), ANprobc(t<0.02))
            xlabel('Time(s)')
            ylabel('Probability of firing')
            grid on    

            saveas ( h, nombreFig, 'png' )
            close(h)  
        end
        end
    end
    
    computeMoreD= true;
    j=(i-3)*delta_num+3;
    while computeMoreD, % computes SACF for every delta, until FDL is obtained
        
        nameDelta= listingDeltas(j).name;
        fileName2=fullfile(folderDeltas,nameDelta);
        [LP_SACF2, dt, lags, SACF2, ANprob2, inputSignal2, fs2, BFList, numLags]= FullPitchModel(fileName2, lags, CFlags1, CFlags2, ANrepr);
        LP_SACFmean2= mean(LP_SACF2,2);
        SACFmean2= mean(SACF2,2);
        
        d_index= Euclidean(SACFmean, SACFmean2);
        d_indexLP= Euclidean(LP_SACFmean, LP_SACFmean2);

        SACFd_index(mod(j-3,delta_num)+1)=d_index;
        LP_SACFd_index(mod(j-3,delta_num)+1)=d_indexLP;
        
        if strcmp(type_model, 'SACF')
            index_used= d_index;
        else if strcmp(type_model, 'LP_SACF')
            index_used= d_indexLP;
            end
        end
        
        if index_used>thresholdD2,
            computeMoreD=false;
            FDL(i-2)= 100*deltas(mod(j-3,delta_num)+1);
        end
        j=j+1;
        if j >= (i-2)*delta_num+3,
            computeMoreD=false;
            FDL(i-2)=50;
        end
        nameDelta2= nameDelta(1:length(nameDelta)-4);
        % SAVE FIGURES: stimulus, total firing probability and SACF
        if plots==1,
            nombreDir= fullfile(outputFolder, 'SACF-FDLdelta');
            if ~isdir(nombreDir),
                mkdir(nombreDir);
            end
            nombreFig= fullfile(outputFolder, 'SACF-FDLdelta', nameDelta2);

            h=figure('Name','Simulation','visible', 'off');
        
            t= (1/fs):(1/fs):(length(inputSignal)/fs);
            subplot(311)
            plot(t(t<0.02),inputSignal2(t<0.02));
            xlabel('Time(s)')
            ylabel('Signal')
            grid on

            subplot(312)
            ANprobmean= mean(ANprob2,1);
            ANprobmean=ANprobmean(round(t*fs));
            plot(t(t<0.02), ANprobmean(t<0.02))
            xlabel('Time(s)')
            ylabel('Probability of firing')
            grid on

            subplot(313)
            plot(lags, SACFmean2)
            xlabel('Lag(s)')
            ylabel('SACF')
            grid on
            
            saveas ( h, nombreFig, 'png' )
            close(h)
            % Plots firing prob for all channels
            else if plots==2, 
                nombreDir= fullfile(outputFolder, 'ProbDisparoCanales', nameDelta2);
                if ~isdir(nombreDir),
                    mkdir(nombreDir);
                end
                for canal=1:size(ANprob,1),

                    nombreFig=fullfile(nombreDir,num2str(BFList(canal)));
                    h=figure('Name','Simulation','visible', 'off');
                    t= (1/fs):(1/fs):(length(inputSignal)/fs);
                    subplot(211)
                    plot(t(t<0.02),inputSignal(t<0.02));
                    xlabel('Time(s)')
                    ylabel('Signal')
                    grid on

                    subplot(212)
                    ANprobc= ANprob(canal,:);
                    ANprobc=ANprobc(round(t*fs));
                    plot(t(t<0.02), ANprobc(t<0.02))
                    xlabel('Time(s)')
                    ylabel('Probability of firing')
                    grid on    
                    saveas ( h, nombreFig, 'png' )
                    close(h)  
                end
                end    
        end % Ends plots
    end % Ends FDL calculation
    
    % Plots FDLs vs. deltas
    if plot_deltas==1,
        nombreDir=fullfile(outputFolder,'Deltas');
        if ~isdir(nombreDir),
            mkdir(nombreDir);
        end
        nombreFigD= fullfile(outputFolder,'Deltas', name2);
        h2=figure('Name','Deltas','visible', 'off');
        plot(deltas, SACFd_index)
        xlabel('Delta (fd/f)')
        ylabel('Euclidean Distance')
        saveas ( h2, nombreFigD, 'png' )
        close(h2)
    end
end % Ends FDL calculation for every frequency

plot(FDLFreqs, FDL)
xlabel('Frequency (Hz)')
ylabel('FDL (%)')
% x= interp1(deltas, SACFd_index, 0.003);
