% Simulations for mistuned harmonic


clear;

spacing='linear';
% Time linear-spacing
minPitch=	30; maxPitch=	10000; numPitches=250;
maxLag=1/minPitch; minLag=1/maxPitch;
lags= linspace(minLag, maxLag, numPitches);
lag_num= length(lags);

% Frequency log-spacing
if strcmp(spacing, 'log')
    a= log10(30);
    b= log10(10000);
    vector= logspace(a, b, numPitches);
    lags= 1./vector;
end
CFlags1=0.5;
CFlags2=10;

% CFlags1=0;
% CFlags2=350;


type_model= 'SACF'; % 'SACF'

plots=0;

ANrepr= 'probability'; % spikes
% ANrepr= 'spikes';

currentF= pwd;
currentF=currentF(1:length(currentF)-15);
currentFWav=strcat(currentF,'wavFileStore');
folderRef = fullfile(currentFWav, 'Mistuned', 'Ref');
folderM = fullfile(currentFWav, 'Mistuned', 'M');

outputFolder= fullfile(currentF, 'Results', 'Mistuned');
if ~isdir(outputFolder),
    mkdir(outputFolder);
end

% Gets all files in directory
listingRef = dir(folderRef);
listingM = dir(folderM);

namesM = struct2cell(listingM);
namesRef = struct2cell(listingRef);
namesM= namesM(1,3:length(namesM));
namesRef= namesRef(1,3:length(namesRef));

num_ref= length(namesRef);
num_M= length(namesM);

ref_SACFs= zeros(num_ref, lag_num);

for i=1:num_ref, % for each ref stimuli, obtains SACF function
    filename= fullfile(folderRef, namesRef{i});
    [LP_SACF, dt, lags, SACF, ANprob, inputSignal, fs, BFList]= FullPitchModel(filename, lags, CFlags1, CFlags2, ANrepr);
%     LP_SACFmean= mean(LP_SACF,2);
    SACFmean= mean(SACF,2);
    ref_SACFs(i,:)=SACFmean;
    
end

D2value= zeros(num_M,1);
bestPitch= zeros(num_M,1);
mistunings= zeros(num_M,1);

for i=1:num_M, % for each mistuning percentage, determines best pitch match
    filename= fullfile(folderM, namesM{i});
    [LP_SACF, dt, lags, SACF, ANprob, inputSignal, fs, BFList]= FullPitchModel(filename, lags, CFlags1, CFlags2, ANrepr);
%     LP_SACFmean= mean(LP_SACF,2);
    SACFmean= mean(SACF,2)';
    mist_index= strfind(filename,')');
    mistuning=str2double(filename(mist_index+1:length(filename)-4))/1000;
    mistunings(i)=mistuning;
    D2=zeros(num_ref,1);
    for j=1:num_ref, % Computes Euclidean distance with all reference stimuli
        D2(j)= Euclidean(SACFmean,ref_SACFs(j,:));
    end
    [D2value(i), index]= min(D2); % Computes minimum Eucl. Dist.
    % Determines pitch from filename
    nameRef=namesRef{index};
    nameRef_len=length(nameRef);
    pitch= nameRef(nameRef_len-10:nameRef_len-7);
    bestPitch(i)=str2double(pitch)/10;
end

mistunings=100*mistunings;
[M, I]= sort(mistunings);
bestPitch= bestPitch(I);
nombreFig= fullfile(outputFolder, 'Mistuned');
nombreFig= strcat(nombreFig,'#', num2str(numPitches), spacing, num2str(floor(10*CFlags1)), '-', num2str(floor(10*CFlags2)));
h=figure('Name','Mistuned','visible', 'off');
plot(M,bestPitch);
xlabel('Mistuning(%)')
ylabel('Pitch(Hz)')
grid on
saveas ( h, nombreFig, 'png' )
saveas ( h, nombreFig, 'fig' )
